# Halmazok s paramterek
set Mezo;        # Mez
set Malom;       # Malom
set Pekseg;      # Pksgek

param Buza {Mezo} >= 0;    # Mezn termelt bza
param MalomKapacitas {Malom} >= 0;  # Malmok kapacitsa
param TavolsagMezoMalom {Mezo, Malom} >= 0;   # Mez s malom kztti tvolsg
param TavolsagMalomPekseg {Malom, Pekseg} >= 0;   # Malom s pksg kztti tvolsg

param TeherautoKapacitas;      # Teheraut kapacitsa (kg)
param OrlesArany;              # rlsi arny (liszt/bza)
param UresFogyasztas;          # res teheraut fogyaszts (l/100 km)
param ValtozoFogyasztas;       # Vltoz fogyaszts (l/kg/100 km)
param Benzinar;                # Benzin ra (Ft/100 km)

# Vltozk
var SzallitasMezoMalom {Mezo, Malom} >= 0;  # Szlltott bza mennyisge mezrl malomba
var SzallitasMalomPekseg {Malom, Pekseg} >= 0;  # Szlltott liszt mennyisge malombl pksgbe

# Korltozsok

# Minden mezrl csak a termelt mennyisg szllthat
s.t. KeszletKorlatozas {m in Mezo}:
    sum {l in Malom} SzallitasMezoMalom[m, l] <= Buza[m];

# Malom kapacitsnak figyelembevtele
s.t. MalomKapacitasKorlatozas {l in Malom}:
    sum {m in Mezo} SzallitasMezoMalom[m, l] <= MalomKapacitas[l];

# rlsi arny figyelembevtele (malombl csak a megfelel lisztmennyisget lehet szlltani)
s.t. OrlesiAranyKorlatozas {l in Malom}:
    sum {p in Pekseg} SzallitasMalomPekseg[l, p] <= sum {m in Mezo} SzallitasMezoMalom[m, l] * OrlesArany;

# Kltsgfggvny
minimize TeljesUzemanyagKoltseg:
    # Mezrl malmokba szllts
    sum {m in Mezo, l in Malom} 
        (UresFogyasztas + ValtozoFogyasztas * SzallitasMezoMalom[m, l]) * TavolsagMezoMalom[m, l] * Benzinar
    + 
    # Malmokbl pksgekbe szllts
    sum {l in Malom, p in Pekseg} 
        (UresFogyasztas + ValtozoFogyasztas * SzallitasMalomPekseg[l, p]) * TavolsagMalomPekseg[l, p] * Benzinar;

# Adatok
data;
set Mezo :=	mezo1	mezo2	mezo3	mezo4;
set Malom :=	malom1	malom2;
set Pekseg :=	pek1	pek2	pek3;

param Buza :=
	mezo1	36526
	mezo2	12368
	mezo3	25634
	mezo4	9999;

param MalomKapacitas :=
	malom1	50000
	malom2	60000;

param TavolsagMezoMalom :	malom1	malom2 :=
	mezo1	201	79
	mezo2	174	143
	mezo3	107	102
	mezo4	130	21;

param TavolsagMalomPekseg :	pek1	pek2	pek3 :=
	malom1	184	98	60
	malom2	79	58	159;

param TeherautoKapacitas := 500;
param OrlesArany := 0.9;
param UresFogyasztas := 10;
param ValtozoFogyasztas := 0.006;
param Benzinar := 600;
end;
